@@ -9,13 +9,19 @@ DASH = '-' * 55
 RESFOLDER_DEFAULT = "%Y-%m-%d_%H-%M-%S"
 SEP = "/"
 RES_FILENAME = "res.pkl"
-DAG_FILENAME = "dag.png"
-TSDAG_FILENAME = "ts_dag.pdf"
-DEP_FILENAME = "dependency.pdf"
+DAG_FILENAME = "dag"
+TSDAG_FILENAME = "ts_dag"
 LOG_FILENAME = "log.txt"
 RESULTS_FILENAME = "results"
 
+
 class LabelType(Enum):
     Lag = "Lag"
     Score = "Score"
-    NoLabels = "NoLabels"
\ No newline at end of file
+    NoLabels = "NoLabels"
+    
+    
+class ImageExt(Enum):
+    PNG = ".png"
+    PDF = ".pdf"
+    JPG = ".jpg"
\ No newline at end of file
